@@ -1,7 +1,7 @@
 import pandas as pd
 from tqdm.autonotebook import tqdm 
 import matplotlib.pyplot as plt
-#from .graph_show import GraphShow
+from .graph_show import GraphShow
 import networkx as nx
 from operator import itemgetter
 import warnings 
@@ -62,17 +62,17 @@ def _cut_legend(legend):
     im_size = im.size
 
     # Define box inside image
-    left = 40
-    top = 65
-    width = 230
-    height = 61
+    left = (im.size[0]/2) - (im.size[0]*3/8)
+    top = (im.size[0]/2) - (im.size[0]/4)
+    width = (im.size[0]*3/4)
+    height = (im.size[0]/4)
 
     # Create Box
     box = (left, top, left+width, top+height)
 
     # Crop Image
     area = im.crop(box)
-    #area.show()
+    area.show()
 
     # Save Image
     area.save(legend, "PNG")
@@ -163,10 +163,12 @@ def _index_generator(file_name):
     for i in range(len(color)):
         L.append(i*3) #i's use for the separation between nodes
     fig = plt.figure(1, figsize=(10, 3))
+    ax = fig.add_subplot(111)
+    ax.set_aspect(aspect=4.6)
     plt.scatter(L, [1  for x in range(len(color))], s = 2000/len(L), color = color, marker = 'D')
     plt.xlim(-1, (len(color)-1)*3+1)
     plt.ylim(0.7, 1.3)
-    plt.axis('on')
+    plt.axis('off')
 
 
     def label_node(xy, text):
@@ -205,7 +207,7 @@ def _index_generator(file_name):
             Nothing 
 
         """
-        y = xy[1] - 0.1  
+        y = xy[1] - 0.25
         plt.text(xy[0], y, text, ha = "center", family = 'sans-serif', size = 12, color = col)
 
 
@@ -222,7 +224,7 @@ def _index_generator(file_name):
             Nothing 
 
         """
-        y = xy[1] + 0.1   
+        y = xy[1] + 0.2   
         plt.text(xy[0], y, text, ha = "center", family='sans-serif', size = 14, color = col)
         
     
@@ -234,7 +236,7 @@ def _index_generator(file_name):
             label_number_upper([L[i],1], Group[L[i]//3][:], color1[i])
 
     # Saving and adjusting the size
-    plt.savefig(file_name + '.png', dpi = 50)
+    plt.savefig(file_name + '.png', dpi = 100)
     plt.close
     
     legend = file_name + '.png'
